pub enum ObservationType {
Alive,
Timeout,
PostMortem,
}Variants
Alive
The actor is alive and was able to snapshot its state within HEARTBEAT
Timeout
An observation could not be made with HEARTBEAT, because the actor had too much work. In that case, in a best effort fashion, the last observed state is returned. The actor will still update its state, as soon as it has finished processing the current message.
PostMortem
The actor has exited. The post-mortem state is joined.